import type { ChapterElement } from '../provider/chapters/shared/types';
import type { SubtitlesProps } from '../provider/subtitles/shared/types';
import type { DefaultLayoutProps, MediaPauseEvent, MediaPlayerInstance, MediaPlayEvent, MediaStartedEvent, MediaTimeUpdateEventDetail, PlayerSrc } from '@vidstack/react';
import type { ErrorData } from 'hls.js';
export type VideoLayoutProps = Omit<DefaultLayoutProps, 'icons' | 'noScrubGesture'>;
export interface SubtitlesTracks {
    src?: string;
    label?: string;
    language?: string;
    kind?: string;
    default?: boolean;
}
export interface EventsConfig {
    /** в случае отсутствия user_id будет отправлен event с признаком anonymous */
    user_id?: string;
    payload?: {
        /** откуда был отправлен event. в случае отсутствия будет отправлен vd_player */
        screen?: string;
        /** идентификатор видео */
        videoid?: string;
    };
    isEmbedded?: boolean;
}
export interface VideoPlayerProps {
    /** источник, который надо воспроизвести */
    src: PlayerSrc;
    /** начать воспроизведение с определенного момента */
    startFrom?: number;
    /** время начала клипа (вырезанный фрагмент) */
    clipStartTime?: number;
    /** время конца клипа (вырезанный фрагмент) */
    clipEndTime?: number;
    /** default = false */
    autoPlay?: boolean;
    /** default = 16/9 */
    aspectRatio?: string;
    /** accessToken будет отправляться при запросах в HLS в заголовке Authorization Bearer */
    accessToken?: string;
    /** ссылка на thumbnails WebVTT */
    thumbnails?: string;
    /** ссылка на превью */
    poster?: string;
    /** data:image/*;base64 которое надо показать пока загружается poster */
    posterFallback?: string;
    /** параметры для субтитров */
    subtitles?: SubtitlesProps;
    /** Список эпизодов */
    chapters?: ChapterElement[];
    /** on started callback */
    onStarted?: (nativeEvent: MediaStartedEvent) => void;
    /** on play callback */
    onPlay?: (player: MediaPlayerInstance, nativeEvent: MediaPlayEvent) => void;
    /** on pause callback */
    onPause?: (player: MediaPlayerInstance, nativeEvent: MediaPauseEvent) => void;
    /** on time update callback */
    onTimeUpdate?: (player: MediaPlayerInstance, nativeEvent: MediaTimeUpdateEventDetail) => void;
    /** on player ready event */
    onPlayerReady?: (player: MediaPlayerInstance) => void;
    /** 'min-controls' - убирает все кнопки контроля кроме play/pause */
    layout?: 'default' | 'min-controls' | 'round';
    /** дополнительные атрибуты для отправки в event tracker */
    events?: EventsConfig;
    /** название видео, для отображения в заголовке и MediaState */
    title?: string;
    /** автор/канал. отображается в MediaState */
    artist?: string;
    /** отображать заголовок */
    withHeader?: boolean;
    /** ссылка на видео, будет открывать при щелчке на title, если withHeader = true */
    linkToVideo?: string;
    /** событие завершения пользовательской перемотки через таймлайн */
    onDragSeekEnd?: (value: number) => void;
    /** on HLS Error */
    onHlsError?: (error: ErrorData) => void;
    /** длительность видео */
    duration?: number;
    /** тип видео */
    streamType?: 'unknown' | 'on-demand' | 'live' | 'live:dvr' | 'll-live' | 'll-live:dvr';
}
